@@ -34,23 +34,6 @@ class Process(object):
         self._system_config_directory = '/etc'
         self._local_config_directory = os.path.realpath(os.path.dirname(sys.argv[0]))
 
-    def _get_config_directory(self):
-        from warnings import warn
-        warn('the config_directory property is deprecated in favor of system_config_directory and will be removed in 1.2.0.', DeprecationWarning)
-        return self._system_config_directory
-
-    def _set_config_directory(self, path):
-        from warnings import warn
-        warn('the config_directory property is deprecated in favor of system_config_directory and will be removed in 1.2.0.', DeprecationWarning)
-        path = os.path.realpath(path)
-        if not os.path.isdir(path):
-            raise ProcessError("config directory %s does not exist" % path)
-        if not os.access(path, os.X_OK | os.R_OK):
-            raise ProcessError("config directory %s is not accessible" % path)
-        self._system_config_directory = path
-
-    config_directory = property(_get_config_directory, _set_config_directory)
-
     def _get_local_config_directory(self):
         return self._local_config_directory
 
