@@ -69,9 +69,9 @@ time.sleep(3)
 try:
     bar = foo
 except NameError, e:
-    log.error("cannot access foo: %s" % str(e))
+    log.error("cannot access foo: %s" % e)
     # Also log the backtrace
-    log.err()
+    log.exception()
 
 log.msg("program done, exiting")
 
